summaryrefslogtreecommitdiff
path: root/scripts
diff options
context:
space:
mode:
authorB. Stack <bgstack15@gmail.com>2024-07-16 15:21:43 -0400
committerB. Stack <bgstack15@gmail.com>2024-07-16 15:21:43 -0400
commit8a35a5728efe9470946425e5bc334f78a1d9001d (patch)
tree3e75aad3c6bf62216bd1f0ed33ca0244ac735efb /scripts
parentdisable 114.0 defuzz of hide-passwordmgr (diff)
downloadlibrewolf-debian-8a35a5728efe9470946425e5bc334f78a1d9001d.tar.gz
librewolf-debian-8a35a5728efe9470946425e5bc334f78a1d9001d.tar.bz2
librewolf-debian-8a35a5728efe9470946425e5bc334f78a1d9001d.zip
v128.0 rc1
Diffstat (limited to 'scripts')
-rw-r--r--scripts/prep-librewolf-dpkg.conf6
-rwxr-xr-xscripts/prep-librewolf-dpkg.sh76
2 files changed, 46 insertions, 36 deletions
diff --git a/scripts/prep-librewolf-dpkg.conf b/scripts/prep-librewolf-dpkg.conf
index 57db46b..9276288 100644
--- a/scripts/prep-librewolf-dpkg.conf
+++ b/scripts/prep-librewolf-dpkg.conf
@@ -4,11 +4,11 @@
# Available options for DISTRO: debian
DISTRO=${DISTRO:-'debian'}
# current version of Firefox package in target distro
-distro_firefox_version=${distro_firefox_version:-'127.0-1'}
+distro_firefox_version=${distro_firefox_version:-'128.0-1'}
# current version of Firefox, as defined by name of the orig tarball.
-firefox_version=${firefox_version:-'127.0'}
+firefox_version=${firefox_version:-'128.0'}
# input git tag of source repo
-source_version=${source_version:-'127.0-1'}
+source_version=${source_version:-'128.0-2'}
settings_commit=${settings_commit:-'master'}
CI_PROJECT_DIR=${CI_PROJECT_DIR:-$(realpath $(dirname $0)/../)}
output_dir=${CI_PROJECT_DIR}/out
diff --git a/scripts/prep-librewolf-dpkg.sh b/scripts/prep-librewolf-dpkg.sh
index 3b47bfe..a1bc032 100755
--- a/scripts/prep-librewolf-dpkg.sh
+++ b/scripts/prep-librewolf-dpkg.sh
@@ -1,7 +1,7 @@
#!/bin/sh
# File: prep-librewolf-dpkg.sh
# Location: https://gitlab.com/bgstack15/librewolf-linux.git
# Latest supported version: librewolf-126.0-1
# Author: bgstack15
# SPDX-License-Identifier: CC-BY-SA-4.0
# Startdate: 2020-11-29
@@ -510,38 +510,48 @@ index b32a6bf..07fd0ed 100644
trigger: { id: "protectionsPanelOpen" },
},
EOF
- # added 111.0, updated 125.0.1
- test -n "1" && cat <<'EOF' > "${debian_dir}/patches/librewolf/disable-pocket.patch"
---- a/browser/base/content/browser.js
-+++ b/browser/base/content/browser.js
-@@ -5314,7 +5314,6 @@ var XULBrowserWindow = {
-
- SafeBrowsingNotificationBox.onLocationChange(aLocationURI);
-
-- SaveToPocket.onLocationChange(window);
-
- let originalURI;
- if (aRequest instanceof Ci.nsIChannel) {
---- a/browser/components/BrowserGlue.sys.mjs
-+++ b/browser/components/BrowserGlue.sys.mjs
-@@ -1440,7 +1440,6 @@ BrowserGlue.prototype = {
- lazy.Normandy.init();
- }
-
-- lazy.SaveToPocket.init();
-
- lazy.ResetPBMPanel.init();
-
---- a/browser/components/moz.build
-+++ b/browser/components/moz.build
-@@ -48,7 +48,6 @@ DIRS += [
- "originattributes",
- "pagedata",
- "places",
-- "pocket",
- "preferences",
- "privatebrowsing",
- "profiles",
+ # added 111.0, updated 128.0.1
+ test -n "" && cat <<'EOF' > "${debian_dir}/patches/librewolf/disable-pocket.patch"
+--- debian/patches/librewolf/disable-pocket.patch 2023-08-30 11:35:20.150917106 -0400
++++ librewolf_128.0/debian/patches/librewolf/disable-pocket.patch 2024-07-16 11:24:38.940187876 -0400
+@@ -1,32 +1,26 @@
+-diff --git a/browser/base/content/browser.js b/browser/base/content/browser.js
+-index 43c84c3..4b4aad2 100644
+ --- a/browser/base/content/browser.js
+ +++ b/browser/base/content/browser.js
+-@@ -5478,7 +5478,6 @@ var XULBrowserWindow = {
++@@ -3630,7 +3630,6 @@ var XULBrowserWindow = {
+
+ SafeBrowsingNotificationBox.onLocationChange(aLocationURI);
+
+ - SaveToPocket.onLocationChange(window);
+
+ let originalURI;
+- if (
+-diff --git a/browser/components/BrowserGlue.jsm b/browser/components/BrowserGlue.sys.mjs
+-index b2479db..7670f08 100644
++ if (aRequest instanceof Ci.nsIChannel) {
+ --- a/browser/components/BrowserGlue.sys.mjs
+ +++ b/browser/components/BrowserGlue.sys.mjs
+-@@ -1274,7 +1274,6 @@ BrowserGlue.prototype = {
++@@ -1500,7 +1500,6 @@ BrowserGlue.prototype = {
+ lazy.Normandy.init();
+ }
+
+ - lazy.SaveToPocket.init();
+
+- AboutHomeStartupCache.init();
++ lazy.ResetPBMPanel.init();
+
+-diff --git a/browser/components/moz.build b/browser/components/moz.build
+-index 3b2126e..32b7831 100644
+ --- a/browser/components/moz.build
+ +++ b/browser/components/moz.build
+-@@ -44,7 +44,6 @@ DIRS += [
++@@ -49,7 +49,6 @@ DIRS += [
+ "originattributes",
+ "pagedata",
+ "places",
EOF
# added 109.0 to patch for debian 109.0 until defuzz-109.0 gets merged
test -n "" && patch -p1 "${debian_dir}/patches/librewolf/disable-data-reporting-at-compile-time.patch" <<'EOF'
@@ -1,7 +1,7 @@
# File: prep-librewolf-dpkg.sh
# Location: https://gitlab.com/bgstack15/librewolf-linux.git
-# Latest supported version: librewolf-126.0-1
+# Latest supported version: librewolf-128.0-1
# Author: bgstack15
# SPDX-License-Identifier: CC-BY-SA-4.0
bgstack15